@@ -123,7 +123,7 @@ class dyagram:
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering LLDP Neighbors - START")
             resp = self._discover_lldp_neighbors_by_restconf(device)
             if not resp:
-                raise
+                raise Exception("Unable to get LLDP Neighbors via RESTCONF")
             self.pbar.update(self.pbar_update_int)
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering LLDP Neighbors - SUCCESSFUL")
         except SSHException:
@@ -201,6 +201,7 @@ class dyagram:
                 except Exception:
                     tb = self.get_traceback()
                     self.log.info(f"EXCEPTION THROWN GETTING DIFFS: {tb}")
+
                 # print to screen the diffs
                 print("DIFFS\n")
                 for ip in diffs:
@@ -257,7 +258,7 @@ class dyagram:
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering routes - START")
             routes = self.discover_routes_restconf(device)
             if not routes:
-                raise
+                raise Exception("Enable to connect via Restconf")
             self.pbar.update(self.pbar_update_int)
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering routes - SUCCESSFUL")
         except SSHException:
@@ -369,7 +370,7 @@ class dyagram:
                            # this is due to deeper dictionary items
 
         diff_resp = DeepDiff(previous_state, current_state, ignore_order=True)
-
+        print(f"DIFF RESPONSE: {diff_resp}")
         if not diff_resp:
             return None
 
@@ -705,7 +706,18 @@ class dyagram:
                 # netmiko_args['device_type'] = os
 
             self.log.info(f"DEVICE: {device} - SSH : CREATING NETMIKO OBJ : _discover_lldp_neighbors_by_ssh")
-            dev = ConnectHandler(**netmiko_args)
+
+            tries = 0
+            while tries < 10:
+                try:
+                    dev = ConnectHandler(**netmiko_args)
+                    tries = 10 # break
+                except:
+                    self.log.info(f"DEVICE: {device} - SSH : FAILED TO CREATE NETMIKO OBJ, TRY AGAIN: _discover_lldp_neighbors_by_ssh")
+                    time.sleep(1)
+                    tries += 1
+
+
             self.log.info(f"DEVICE: {device} - SSH : CREATED NETMIKO OBJ : _discover_lldp_neighbors_by_ssh")
             self.log.info(f"DEVICE: {device} - SSH : SETTING ENABLE")
 
